# Эталоны

Для обозначения эталонного метода бенчмарка используйте аннотацию `&Эталон`.
Это позволяет сравнивать производительность других методов с выбранным эталоном.

### API

```bsl
// Установка текущего бенчмарка в качестве эталона
ДескрипторБенчмарка.ИспользоватьКакЭталон();

// Снятие эталонного статуса с бенчмарка
ДескрипторБенчмарка.ИспользоватьКакЭталон(Ложь);
```

### Пример

```bsl
&Бенчмарк
Процедура Задержка50() Экспорт
	Приостановить(50);
КонецПроцедуры

&Бенчмарк
&Эталон
Процедура Задержка100() Экспорт
	Приостановить(100);
КонецПроцедуры

&Бенчмарк
Процедура Задержка150() Экспорт
	Приостановить(150);
КонецПроцедуры
```

### Вывод

В отчете автоматически добавляется колонка `Ratio`, показывающая отношение среднего времени выполнения (Mean) к эталону.

| Method      | Baseline |     Mean |   StdErr |   StdDev | Ratio |   Median |  Op/s |
|-------------|----------|---------:|---------:|---------:|------:|---------:|------:|
| Задержка100 | true     | 100.9 ms | 20.05 us | 77.65 us |     1 | 100.9 ms | 9.910 |
| Задержка150 | false    | 150.9 ms | 15.45 us | 59.83 us | 1.496 | 150.9 ms | 6.625 |
| Задержка50  | false    | 50.91 ms | 19.12 us | 74.03 us | 0.505 | 50.92 ms | 19.64 |

## Эталоны по категориям

Для использования нескольких эталонов в одном классе применяйте категории. Каждая категория может иметь собственный эталон.

### Пример

```bsl
&Бенчмарк
&Категория("Быстрый")
&Эталон
Процедура Задержка50() Экспорт
	Приостановить(50);
КонецПроцедуры

&Бенчмарк
&Категория("Быстрый")
Процедура Задержка100() Экспорт
	Приостановить(100);
КонецПроцедуры

&Бенчмарк
&Категория("Медленный")
&Эталон
Процедура Задержка300() Экспорт
	Приостановить(300);
КонецПроцедуры

&Бенчмарк
&Категория("Медленный")
Процедура Задержка350() Экспорт
	Приостановить(350);
КонецПроцедуры
```

### Вывод

| Method      | Categories | Baseline |     Mean |   StdErr |   StdDev | Ratio |   Median |  Op/s |
|-------------|------------|----------|---------:|---------:|---------:|------:|---------:|------:|
| Задержка50  | Быстрый    | true     | 50.88 ms | 20.70 us | 80.18 us |     1 | 50.86 ms | 19.65 |
| Задержка100 | Быстрый    | false    | 100.9 ms | 21.15 us | 81.92 us | 1.983 | 100.9 ms | 9.911 |
| Задержка300 | Медленный  | true     | 301.0 ms | 16.55 us | 64.08 us |     1 | 301.0 ms | 3.323 |
| Задержка350 | Медленный  | false    | 350.9 ms | 25.87 us | 100.2 us | 1.166 | 350.9 ms | 2.850 |